summaryrefslogtreecommitdiffstats
path: root/src/com/android/wallpaperpicker/WallpaperPickerActivity.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/wallpaperpicker/WallpaperPickerActivity.java')
-rw-r--r--src/com/android/wallpaperpicker/WallpaperPickerActivity.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/com/android/wallpaperpicker/WallpaperPickerActivity.java b/src/com/android/wallpaperpicker/WallpaperPickerActivity.java
index 094d3ce..f303f93 100644
--- a/src/com/android/wallpaperpicker/WallpaperPickerActivity.java
+++ b/src/com/android/wallpaperpicker/WallpaperPickerActivity.java
@@ -202,7 +202,7 @@ public class WallpaperPickerActivity extends WallpaperCropActivity
new View.OnClickListener() {
@Override
public void onClick(View v) {
// Ensure that a tile is slelected and loaded.
if (mSelectedTile != null && mCropView.getTileSource() != null) {
// Prevent user from selecting any new tile.
mWallpaperStrip.setVisibility(View.GONE);
@@ -211,9 +211,9 @@ public class WallpaperPickerActivity extends WallpaperCropActivity
WallpaperTileInfo info = (WallpaperTileInfo) mSelectedTile.getTag();
info.onSave(WallpaperPickerActivity.this);
} else {
- // no tile was selected, so we just finish the activity and go back
- setResult(Activity.RESULT_OK);
- finish();
+ // This case shouldn't be possible, since "Set wallpaper" is disabled
+ // until user clicks on a title.
+ Log.w(TAG, "\"Set wallpaper\" was clicked when no tile was selected");
}
}
});
@@ -232,10 +232,10 @@ public class WallpaperPickerActivity extends WallpaperCropActivity
}
return;
}
- setWallpaperButtonEnabled(true);
WallpaperTileInfo info = (WallpaperTileInfo) v.getTag();
if (info.isSelectable() && v.getVisibility() == View.VISIBLE) {
selectTile(v);
+ setWallpaperButtonEnabled(true);
}
info.onClick(this);
}
@@ -202,7 +202,7 @@ public class WallpaperPickerActivity extends WallpaperCropActivity
public void onClick(View v) {
- // Ensure that a tile is slelected and loaded.
+ // Ensure that a tile is selected and loaded.
if (mSelectedTile != null && mCropView.getTileSource() != null) {
// Prevent user from selecting any new tile.